/*
 * $Id: local.h.samp,v 1.20 2001/07/25 21:51:47 geoff Exp $
 */

/*
 * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All modifications to the source code must be clearly marked as
 *    such.  Binary redistributions based on modified source code
 *    must be clearly marked as modified versions in the documentation
 *    and/or other materials provided with the distribution.
 * 4. Any web site or other electronic service that offers ispell for
 *    download or other electronic transfer as a separate entity, in
 *    either source or binary form, must also include a prominent statement
 *    indicating that information about ispell can be obtained from the
 *    following Web site URL:
 *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
 *    If the offering service supports hyperlinks, the aforementioned
 *    Web site must also be offered as a hyperlink.  Condition #4 does
 *    not apply if ispell is offered only as part of a larger, aggregated
 *    product such as a word processor or packaged operating system.
 * 5. The name of Geoff Kuenning may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF KUENNING OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * This file is a sample local.h file.  It shows what I believe nearly every
 * site will want to include in their local.h.  You will probably want to
 * expand this file;  see "config.X" to learn of #defines that you might
 * like to add to.
 */

/*
 * $Log: local.h.samp,v $
 * Revision 1.20  2001/07/25 21:51:47  geoff
 * Minor license update.
 *
 * Revision 1.19  2001/07/23 20:24:04  geoff
 * Update the copyright and the license.
 *
 * Revision 1.18  2001/05/30 21:14:47  geoff
 * Invert the fcntl/mkstemp options so they will default to being used.
 *
 * Revision 1.17  2001/05/30 21:04:25  geoff
 * Add HAS_FCNTL_H and HAS_MKSTEMP.  Also give better comments on the USG
 * option.
 *
 * Revision 1.16  1999/01/08 04:34:43  geoff
 * Get rid of ELISPDIR and TEXINFODIR
 *
 * Revision 1.15  1999/01/07  01:57:57  geoff
 * Update the copyright.
 *
 * Revision 1.14  1995/01/08  23:23:56  geoff
 * Do some minor clarification of the instructional comments.
 *
 * Revision 1.13  1994/05/17  06:37:25  geoff
 * Add one more item of warning advice to the comments.
 *
 * Revision 1.12  1994/02/07  06:00:00  geoff
 * Add a warning about shell processing restrictions
 *
 * Revision 1.11  1994/01/25  07:11:50  geoff
 * Get rid of all old RCS log lines in preparation for the 3.1 release.
 *
 */

/*
 * WARNING WARNING WARNING
 *
 * This file is *NOT* a normal C header file!  Although it uses C
 * syntax and is included in C programs, it is also processed by shell
 * scripts that are very stupid about format.
 *
 * Do not try to use #if constructs to configure this file for more
 * than one configuration.  Do not place whitespace after the "#" in
 * "#define".  Do not attempt to disable lines by commenting them out.
 * Do not use backslashes to reduce the length of long lines.
 * None of these things will work the way you expect them to.
 *
 * WARNING WARNING WARNING
 */

#define MINIMENU      1	 /* Display a mini-menu at the bottom of the screen */
#define USG           1	 /* Define on System V or if term.c won't compile */
#define TRUNCATEBAK   1  /* Truncate .BAK files to MAXNAMLEN characters   */
#define REGEX_LOOKUP  1  /* enable regexp vocab search */
#define MAXCONTEXT    5  /* show up to 5 lines of text on screen, also use less memory */

#define HAS_RENAME    1
#define SIGNAL_TYPE   int
#define MAXPATHLEN    _MAX_PATH
#define MAXNAMLEN     _MAX_FNAME

#define GETKEYSTROKE() os2_GETKEYSTROKE()

extern char * re_comp(const char * expr);
extern int 	  re_exec(const char * pat);

#define REGCMP(str)             re_comp (str)
#define REGEX(re, str, dummy)   re_exec (str)
#define HAVE_STRING_H           1

/*
 * Important directory paths
 */

#define TEMPNAME      os2_TEMPNAME
#define LIBDIR        os2_LIBDIR

/*
 * Place any locally-required #include statements here
 */

#include <stdio.h>
#include <stdlib.h>
#include <setjmp.h>
#include <dos.h>
#include <fcntl.h>

/*
 * Local functions
 */

void  spaceabort(void);                /* raise 'out-of-disk-space' condition */
void  safe_putc(int __c, FILE *__fp);  /* run spaceabort() on error           */
char *lastpathchar(char *s);           /* last pos of slash or backslash      */
char *os2_init(char *argv0);
int   os2_GETKEYSTROKE(void);

extern char os2_TEMPNAME[MAXPATHLEN];
extern char os2_LIBDIR[MAXPATHLEN];

extern int     safewrite_active;
extern jmp_buf safewritejmpbuf;

#define beginsafewrite() (safewrite_active = 1, setjmp(safewritejmpbuf))
#define endsafewrite()   (safewrite_active = 0)

/*
 * Look like shellescape() prototype not defined under some conditions
 */

int  shellescape(char *buf);

/*
 * Local implementations of some system functions
 */

#ifdef __WATCOMC__
int   mkstemp(char *name);
FILE *popen(char *file, char *mode);

#pragma disable_message(202);

#endif
